@@ -14,7 +14,7 @@ use XS::Object::Magic 0.04 ();
 package Git::XS;
 use Mo qw'default build required';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -23,7 +23,14 @@ sub BUILD { shift->_build }
 
 has repo => ( required => 1 );
 
-sub repo_exists {
+sub init {
+    my $self = shift;
+    my $bare = (@_ and shift eq -bare) ? 1 : 0;
+    croak("Invalid arguments passed to init") if @_;
+    $self->_init($bare);
+}
+
+sub _repo_exists {
     my $self = shift;
     my $repo = shift;
     return -f "$repo/.git/conf" ? 1 : 0;
@@ -74,3 +81,16 @@ programs in your PATH:
     cmake - to build libgit2
 
 In the future, this module might use your system's copy of libgit2.
+
+=head1 METHODS
+
+=over
+
+=item Git::XS->new(repo => $repo)
+
+Create a new Git::XS object for dealing with a git repository.
+
+=item $git->init([-bare])
+
+Initialize a repo if it doesn't exist. You can pass '-bare' to create a bare
+repo.
